ca_cancel
open | /demo/ca_cancel.html |
assertTextPresent | action-cancel |
click | css=#standard .with |
waitForText | logger | action
assertText | logger | action
click | css=#standard .without |
waitForText | logger | action
assertText | logger | action
click | css=#standard .with |
waitForText | logger | actionaction
assertText | logger | actionaction
click | log-reset |
click | css=#alias .with |
waitForText | logger | action
assertText | logger | action
click | css=#alias .without |
waitForText | logger | action
assertText | logger | action
click | css=#alias .with |
waitForText | logger | actionaction
assertText | logger | actionaction